[Python-3000-checkins] r62218 - python/branches/py3k/Lib/io.py

benjamin.peterson python-3000-checkins at python.org
Tue Apr 8 00:27:41 CEST 2008


Author: benjamin.peterson
Date: Tue Apr  8 00:27:34 2008
New Revision: 62218

Modified:
   python/branches/py3k/Lib/io.py
Log:
fixed outdated  annotation of readinto in io


Modified: python/branches/py3k/Lib/io.py
==============================================================================
--- python/branches/py3k/Lib/io.py	(original)
+++ python/branches/py3k/Lib/io.py	Tue Apr  8 00:27:34 2008
@@ -487,8 +487,8 @@
             res += data
         return bytes(res)
 
-    def readinto(self, b: bytes) -> int:
-        """readinto(b: bytes) -> int.  Read up to len(b) bytes into b.
+    def readinto(self, b: bytearray) -> int:
+        """readinto(b: bytearray) -> int.  Read up to len(b) bytes into b.
 
         Returns number of bytes read (0 for EOF), or None if the object
         is set not to block as has no data to read.
@@ -563,8 +563,8 @@
         """
         self._unsupported("read")
 
-    def readinto(self, b: bytes) -> int:
-        """readinto(b: bytes) -> int.  Read up to len(b) bytes into b.
+    def readinto(self, b: bytearray) -> int:
+        """readinto(b: bytearray) -> int.  Read up to len(b) bytes into b.
 
         Like read(), this may issue multiple reads to the underlying
         raw stream, unless the latter is 'interactive' (XXX or a


More information about the Python-3000-checkins mailing list